#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 uglymemo
version:              0.1.0.1
visibility:           public
id:                   uglymemo-0.1.0.1-HKV10OmQmu17xB3HkisM7k
key:                  uglymemo-0.1.0.1-HKV10OmQmu17xB3HkisM7k
license:              LicenseRef-PublicDomain
maintainer:           lennart@augustsson.net
author:               Lennart Augustsson
synopsis:             A simple (but internally ugly) memoization function.
description:
    A simple (but internally ugly) memoization function.

    * New in 0.1.0.1: Make it exception safe.

category:             Data
abi:                  2d092a92d9f0286493147bd8d035bc3e
exposed:              True
exposed-modules:      Data.MemoUgly
import-dirs:          /usr/lib/ghc-8.10.5/site-local/uglymemo-0.1.0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/uglymemo-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/uglymemo-0.1.0.1
hs-libraries:         HSuglymemo-0.1.0.1-HKV10OmQmu17xB3HkisM7k
depends:              base-4.14.2.0 containers-0.6.4.1
haddock-interfaces:   /usr/share/doc/haskell-uglymemo/html/uglymemo.haddock
haddock-html:         /usr/share/doc/haskell-uglymemo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

